(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    102000,       2349]*)
(*NotebookOutlinePosition[    106210,       2450]*)
(*  CellTagsIndexPosition[    106096,       2443]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ReplaceEdges", "ObjectName",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[TextData[{
  "\[FilledSmallSquare] ReplaceEdges[ ",
  StyleBox["model, ",
    FontSlant->"Italic"],
  StyleBox["opts",
    FontSlant->"Italic"],
  " ] replaces the edges in ",
  StyleBox["model",
    FontSlant->"Italic"],
  " according to the specified options",
  "."
}], "Usage",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell["\<\
\[FilledSmallSquare] ReplaceEdges understands the following \
options:\
\>", "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[TextData[Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox["InteractionNeighborhood",
              FontFamily->"Courier"], " ", Cell[TextData[{
              "A ",
              StyleBox["Combinatorica",
                FontSlant->"Italic"],
              " graph specifying t",
              "he new interaction neighborhood."
            }]]},
          {
            StyleBox["UpdateNeighborhood",
              FontFamily->"Courier"], " ", Cell[TextData[{
              "A ",
              StyleBox["Combinatorica ",
                FontSlant->"Italic"],
              "graph specifying t",
              "he new update neighborhood"
            }]]},
          {
            StyleBox["Neighborhood",
              FontFamily->"Courier"], " ", Cell[TextData[{
              "A ",
              StyleBox["Combinatorica",
                FontSlant->"Italic"],
              " g",
              "raph for both the interaction and update neighborhood"
            }]]},
          {
            StyleBox["UseInteractionNeighborhoodWeights",
              FontFamily->"Courier"], "False", Cell[
            "Assign probabilities to the new interaction edges"]},
          {
            StyleBox["UseUpdateNeighborhoodWeights",
              FontFamily->"Courier"], "False", Cell[
            "Assign probabilities to the new update edges"]},
          {
            StyleBox["NeighborhoodsToDraw",
              FontFamily->"Courier"], \({Interaction}\), Cell[
            "What neighborhoods to draw"]}
          }], TraditionalForm]]]], "3ColumnTable",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[TextData[{
  "\[FilledSmallSquare] It is an error to specify a value for ",
  StyleBox["Neighborhood",
    FontFamily->"Courier"],
  " in addition to values for ",
  StyleBox["InteractionNeighborhood",
    FontFamily->"Courier"],
  " or ",
  StyleBox["UpdateNeighborhood",
    FontFamily->"Courier"],
  "."
}], "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell["\<\
\[FilledSmallSquare] The new neighborhoods must have the same \
number of vertices as the original model.\
\>", "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[TextData[{
  "\[FilledSmallSquare] ",
  StyleBox["NeighborhoodsToDraw",
    FontFamily->"Courier"],
  " takes the same options as ",
  StyleBox["NeighborhoodsToDraw",
    FontFamily->"Courier"],
  " in the function ",
  StyleBox["LocalInteractionModel",
    FontFamily->"Courier"],
  "."
}], "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{

Cell["Example", "ExampleSection",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[BoxData[
    \(<< LocalInteractions`LocalInteractions`\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = LocalInteractionModel[];\)\), "\[IndentingNewLine]", 
    \(\(ShowGraph[m];\)\)}], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0454545 0.909091 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.04545 .04545 m
.14646 .04545 L
s
.04545 .04545 m
.04545 .14646 L
s
.14646 .04545 m
.24747 .04545 L
s
.14646 .04545 m
.14646 .14646 L
s
.24747 .04545 m
.34848 .04545 L
s
.24747 .04545 m
.24747 .14646 L
s
.34848 .04545 m
.44949 .04545 L
s
.34848 .04545 m
.34848 .14646 L
s
.44949 .04545 m
.55051 .04545 L
s
.44949 .04545 m
.44949 .14646 L
s
.55051 .04545 m
.65152 .04545 L
s
.55051 .04545 m
.55051 .14646 L
s
.65152 .04545 m
.75253 .04545 L
s
.65152 .04545 m
.65152 .14646 L
s
.75253 .04545 m
.85354 .04545 L
s
.75253 .04545 m
.75253 .14646 L
s
.85354 .04545 m
.95455 .04545 L
s
.85354 .04545 m
.85354 .14646 L
s
.95455 .04545 m
.95455 .14646 L
s
.04545 .14646 m
.14646 .14646 L
s
.04545 .14646 m
.04545 .24747 L
s
.14646 .14646 m
.24747 .14646 L
s
.14646 .14646 m
.14646 .24747 L
s
.24747 .14646 m
.34848 .14646 L
s
.24747 .14646 m
.24747 .24747 L
s
.34848 .14646 m
.44949 .14646 L
s
.34848 .14646 m
.34848 .24747 L
s
.44949 .14646 m
.55051 .14646 L
s
.44949 .14646 m
.44949 .24747 L
s
.55051 .14646 m
.65152 .14646 L
s
.55051 .14646 m
.55051 .24747 L
s
.65152 .14646 m
.75253 .14646 L
s
.65152 .14646 m
.65152 .24747 L
s
.75253 .14646 m
.85354 .14646 L
s
.75253 .14646 m
.75253 .24747 L
s
.85354 .14646 m
.95455 .14646 L
s
.85354 .14646 m
.85354 .24747 L
s
.95455 .14646 m
.95455 .24747 L
s
.04545 .24747 m
.14646 .24747 L
s
.04545 .24747 m
.04545 .34848 L
s
.14646 .24747 m
.24747 .24747 L
s
.14646 .24747 m
.14646 .34848 L
s
.24747 .24747 m
.34848 .24747 L
s
.24747 .24747 m
.24747 .34848 L
s
.34848 .24747 m
.44949 .24747 L
s
.34848 .24747 m
.34848 .34848 L
s
.44949 .24747 m
.55051 .24747 L
s
.44949 .24747 m
.44949 .34848 L
s
.55051 .24747 m
.65152 .24747 L
s
.55051 .24747 m
.55051 .34848 L
s
.65152 .24747 m
.75253 .24747 L
s
.65152 .24747 m
.65152 .34848 L
s
.75253 .24747 m
.85354 .24747 L
s
.75253 .24747 m
.75253 .34848 L
s
.85354 .24747 m
.95455 .24747 L
s
.85354 .24747 m
.85354 .34848 L
s
.95455 .24747 m
.95455 .34848 L
s
.04545 .34848 m
.14646 .34848 L
s
.04545 .34848 m
.04545 .44949 L
s
.14646 .34848 m
.24747 .34848 L
s
.14646 .34848 m
.14646 .44949 L
s
.24747 .34848 m
.34848 .34848 L
s
.24747 .34848 m
.24747 .44949 L
s
.34848 .34848 m
.44949 .34848 L
s
.34848 .34848 m
.34848 .44949 L
s
.44949 .34848 m
.55051 .34848 L
s
.44949 .34848 m
.44949 .44949 L
s
.55051 .34848 m
.65152 .34848 L
s
.55051 .34848 m
.55051 .44949 L
s
.65152 .34848 m
.75253 .34848 L
s
.65152 .34848 m
.65152 .44949 L
s
.75253 .34848 m
.85354 .34848 L
s
.75253 .34848 m
.75253 .44949 L
s
.85354 .34848 m
.95455 .34848 L
s
.85354 .34848 m
.85354 .44949 L
s
.95455 .34848 m
.95455 .44949 L
s
.04545 .44949 m
.14646 .44949 L
s
.04545 .44949 m
.04545 .55051 L
s
.14646 .44949 m
.24747 .44949 L
s
.14646 .44949 m
.14646 .55051 L
s
.24747 .44949 m
.34848 .44949 L
s
.24747 .44949 m
.24747 .55051 L
s
.34848 .44949 m
.44949 .44949 L
s
.34848 .44949 m
.34848 .55051 L
s
.44949 .44949 m
.55051 .44949 L
s
.44949 .44949 m
.44949 .55051 L
s
.55051 .44949 m
.65152 .44949 L
s
.55051 .44949 m
.55051 .55051 L
s
.65152 .44949 m
.75253 .44949 L
s
.65152 .44949 m
.65152 .55051 L
s
.75253 .44949 m
.85354 .44949 L
s
.75253 .44949 m
.75253 .55051 L
s
.85354 .44949 m
.95455 .44949 L
s
.85354 .44949 m
.85354 .55051 L
s
.95455 .44949 m
.95455 .55051 L
s
.04545 .55051 m
.14646 .55051 L
s
.04545 .55051 m
.04545 .65152 L
s
.14646 .55051 m
.24747 .55051 L
s
.14646 .55051 m
.14646 .65152 L
s
.24747 .55051 m
.34848 .55051 L
s
.24747 .55051 m
.24747 .65152 L
s
.34848 .55051 m
.44949 .55051 L
s
.34848 .55051 m
.34848 .65152 L
s
.44949 .55051 m
.55051 .55051 L
s
.44949 .55051 m
.44949 .65152 L
s
.55051 .55051 m
.65152 .55051 L
s
.55051 .55051 m
.55051 .65152 L
s
.65152 .55051 m
.75253 .55051 L
s
.65152 .55051 m
.65152 .65152 L
s
.75253 .55051 m
.85354 .55051 L
s
.75253 .55051 m
.75253 .65152 L
s
.85354 .55051 m
.95455 .55051 L
s
.85354 .55051 m
.85354 .65152 L
s
.95455 .55051 m
.95455 .65152 L
s
.04545 .65152 m
.14646 .65152 L
s
.04545 .65152 m
.04545 .75253 L
s
.14646 .65152 m
.24747 .65152 L
s
.14646 .65152 m
.14646 .75253 L
s
.24747 .65152 m
.34848 .65152 L
s
.24747 .65152 m
.24747 .75253 L
s
.34848 .65152 m
.44949 .65152 L
s
.34848 .65152 m
.34848 .75253 L
s
.44949 .65152 m
.55051 .65152 L
s
.44949 .65152 m
.44949 .75253 L
s
.55051 .65152 m
.65152 .65152 L
s
.55051 .65152 m
.55051 .75253 L
s
.65152 .65152 m
.75253 .65152 L
s
.65152 .65152 m
.65152 .75253 L
s
.75253 .65152 m
.85354 .65152 L
s
.75253 .65152 m
.75253 .75253 L
s
.85354 .65152 m
.95455 .65152 L
s
.85354 .65152 m
.85354 .75253 L
s
.95455 .65152 m
.95455 .75253 L
s
.04545 .75253 m
.14646 .75253 L
s
.04545 .75253 m
.04545 .85354 L
s
.14646 .75253 m
.24747 .75253 L
s
.14646 .75253 m
.14646 .85354 L
s
.24747 .75253 m
.34848 .75253 L
s
.24747 .75253 m
.24747 .85354 L
s
.34848 .75253 m
.44949 .75253 L
s
.34848 .75253 m
.34848 .85354 L
s
.44949 .75253 m
.55051 .75253 L
s
.44949 .75253 m
.44949 .85354 L
s
.55051 .75253 m
.65152 .75253 L
s
.55051 .75253 m
.55051 .85354 L
s
.65152 .75253 m
.75253 .75253 L
s
.65152 .75253 m
.65152 .85354 L
s
.75253 .75253 m
.85354 .75253 L
s
.75253 .75253 m
.75253 .85354 L
s
.85354 .75253 m
.95455 .75253 L
s
.85354 .75253 m
.85354 .85354 L
s
.95455 .75253 m
.95455 .85354 L
s
.04545 .85354 m
.14646 .85354 L
s
.04545 .85354 m
.04545 .95455 L
s
.14646 .85354 m
.24747 .85354 L
s
.14646 .85354 m
.14646 .95455 L
s
.24747 .85354 m
.34848 .85354 L
s
.24747 .85354 m
.24747 .95455 L
s
.34848 .85354 m
.44949 .85354 L
s
.34848 .85354 m
.34848 .95455 L
s
.44949 .85354 m
.55051 .85354 L
s
.44949 .85354 m
.44949 .95455 L
s
.55051 .85354 m
.65152 .85354 L
s
.55051 .85354 m
.55051 .95455 L
s
.65152 .85354 m
.75253 .85354 L
s
.65152 .85354 m
.65152 .95455 L
s
.75253 .85354 m
.85354 .85354 L
s
.75253 .85354 m
.75253 .95455 L
s
.85354 .85354 m
.95455 .85354 L
s
.85354 .85354 m
.85354 .95455 L
s
.95455 .85354 m
.95455 .95455 L
s
.04545 .95455 m
.14646 .95455 L
s
.14646 .95455 m
.24747 .95455 L
s
.24747 .95455 m
.34848 .95455 L
s
.34848 .95455 m
.44949 .95455 L
s
.44949 .95455 m
.55051 .95455 L
s
.55051 .95455 m
.65152 .95455 L
s
.65152 .95455 m
.75253 .95455 L
s
.75253 .95455 m
.85354 .95455 L
s
.85354 .95455 m
.95455 .95455 L
s
1 0 0 r
.025 w
.04545 .04545 Mdot
.14646 .04545 Mdot
.24747 .04545 Mdot
.34848 .04545 Mdot
.44949 .04545 Mdot
.55051 .04545 Mdot
.65152 .04545 Mdot
.75253 .04545 Mdot
.85354 .04545 Mdot
.95455 .04545 Mdot
.04545 .14646 Mdot
.14646 .14646 Mdot
.24747 .14646 Mdot
.34848 .14646 Mdot
.44949 .14646 Mdot
.55051 .14646 Mdot
.65152 .14646 Mdot
.75253 .14646 Mdot
.85354 .14646 Mdot
.95455 .14646 Mdot
.04545 .24747 Mdot
.14646 .24747 Mdot
.24747 .24747 Mdot
.34848 .24747 Mdot
.44949 .24747 Mdot
.55051 .24747 Mdot
.65152 .24747 Mdot
.75253 .24747 Mdot
.85354 .24747 Mdot
.95455 .24747 Mdot
.04545 .34848 Mdot
.14646 .34848 Mdot
.24747 .34848 Mdot
.34848 .34848 Mdot
.44949 .34848 Mdot
.55051 .34848 Mdot
.65152 .34848 Mdot
.75253 .34848 Mdot
.85354 .34848 Mdot
.95455 .34848 Mdot
.04545 .44949 Mdot
.14646 .44949 Mdot
.24747 .44949 Mdot
.34848 .44949 Mdot
.44949 .44949 Mdot
.55051 .44949 Mdot
.65152 .44949 Mdot
.75253 .44949 Mdot
.85354 .44949 Mdot
.95455 .44949 Mdot
.04545 .55051 Mdot
.14646 .55051 Mdot
.24747 .55051 Mdot
.34848 .55051 Mdot
.44949 .55051 Mdot
.55051 .55051 Mdot
.65152 .55051 Mdot
.75253 .55051 Mdot
.85354 .55051 Mdot
.95455 .55051 Mdot
.04545 .65152 Mdot
.14646 .65152 Mdot
.24747 .65152 Mdot
.34848 .65152 Mdot
.44949 .65152 Mdot
.55051 .65152 Mdot
.65152 .65152 Mdot
.75253 .65152 Mdot
.85354 .65152 Mdot
.95455 .65152 Mdot
.04545 .75253 Mdot
.14646 .75253 Mdot
.24747 .75253 Mdot
.34848 .75253 Mdot
.44949 .75253 Mdot
.55051 .75253 Mdot
.65152 .75253 Mdot
.75253 .75253 Mdot
.85354 .75253 Mdot
.95455 .75253 Mdot
.04545 .85354 Mdot
.14646 .85354 Mdot
.24747 .85354 Mdot
.34848 .85354 Mdot
.44949 .85354 Mdot
.55051 .85354 Mdot
.65152 .85354 Mdot
.75253 .85354 Mdot
.85354 .85354 Mdot
.95455 .85354 Mdot
.04545 .95455 Mdot
.14646 .95455 Mdot
.24747 .95455 Mdot
.34848 .95455 Mdot
.44949 .95455 Mdot
.55051 .95455 Mdot
.65152 .95455 Mdot
.75253 .95455 Mdot
.85354 .95455 Mdot
.95455 .95455 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[2]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Joooo
o`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo000:ooooo`Go
o`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Go
o`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000Wooooo1ooo000Fooooo`Ooo`00
5_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`00
5_ooool7ool001Kooooo1ooo000;ooooo`002Oooool7ool001Ko00001ooo000Fo`0000Ooo`005_l0
0007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l0
0007ool000_ooooo0009ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7
ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`002oooool0
00[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool0
01Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000<ooooo`002oooool3ool001[o
oooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[o
oooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo000=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000;ooooo`?oo`006_ooool3ool001[ooooo0ooo000J
ooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000J
ooooo`?oo`003Oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hoooo
o`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000<oooo
o`002Oooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Oo
o`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo0009ooooo`Ooo`00
5_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`00
5_l00007ool001Ko00001ooo000Fo`0000Ooo`002oooool000Wooooo1ooo000Fooooo`Ooo`005_oo
ool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_oo
ool7ool001Kooooo1ooo000;ooooo`002_ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5
ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5
ool000cooooo000;ooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool0
01[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`003Oooool000go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000_ooooo0ooo
000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo
000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000=ooooo`002_ooool5ool001Sooooo1Ooo000H
ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000H
ooooo`Goo`006?ooool5ool000cooooo0009ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Foooo
o`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Foooo
o`Ooo`002oooool000Wooooo1ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Oo
o`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000;ooooo`00
2Oooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`00
5_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo000:ooooo`Goo`006?oo
ool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?oo
ool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000_ooooo0ooo000Jooooo`?oo`006_ooool3
ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3
ool001[ooooo0ooo000=ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo
0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo
000:ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo
000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000Wooooo1ooo000F
ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000F
ooooo`Ooo`005_ooool7ool001Kooooo1ooo000;ooooo`002Oooool7ool001Ko00001ooo000Fo`00
00Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`00
00Ooo`005_l00007ool000_ooooo0009ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Oo
o`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Oo
o`002oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`00
6?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000<ooooo`002ooo
ool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_oo
ool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo000=ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000;ooooo`?oo`006_ooool3ool001[o
oooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[o
oooo0ooo000Jooooo`?oo`003Oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo
1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo
1Ooo000<ooooo`002Oooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo
000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo0009
ooooo`Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000F
o`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`002oooool000Wooooo1ooo000Foooo
o`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Foooo
o`Ooo`005_ooool7ool001Kooooo1ooo000;ooooo`002_ooool5ool001Sooooo1Ooo000Hooooo`Go
o`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Go
o`006?ooool5ool000cooooo000;ooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`00
6_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`00
3Oooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
00_ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool0
01[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000=ooooo`002_ooool5ool001So
oooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001So
oooo1Ooo000Hooooo`Goo`006?ooool5ool000cooooo0009ooooo`Ooo`005_l00007ool001Ko0000
1ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko0000
1ooo000Fo`0000Ooo`002oooool000Wooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo
000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo
000;ooooo`002Oooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000F
ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo000:oooo
o`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hoooo
o`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000_ooooo0ooo000Jooooo`?o
o`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?o
o`006_ooool3ool001[ooooo0ooo000=ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3
ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3
ool000gooooo000:ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool0
01Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000Wo
oooo1ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko
00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000;ooooo`002Oooool7ool001Kooooo
1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo
1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo0009ooooo`Ooo`005_ooool7ool001Kooooo1ooo
000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo
000Fooooo`Ooo`002oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000H
ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000<
ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Joooo
o`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo000=ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00co
oooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000=ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00cooooo000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo000;ooooo`?oo`006_oo
ool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_oo
ool3ool001[ooooo0ooo000Jooooo`?oo`003Oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5
ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5
ool001Sooooo1Ooo000<ooooo`002Oooool7ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool0
01Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool0
00_ooooo0009ooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Ko
oooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`002oooool000Wooooo
1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo
1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000;ooooo`002_ooool5ool001Sooooo1Ooo
000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo
000Hooooo`Goo`006?ooool5ool000cooooo000;ooooo`?oo`006_ooool3ool001[ooooo0ooo000J
ooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000J
ooooo`?oo`003Oooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?oo
ool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
3?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03?ooool000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool000gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool03?ooool000_ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`00
6_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000=ooooo`002_oo
ool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?oo
ool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool000cooooo0009ooooo`Ooo`005_l00007
ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l00007
ool001Ko00001ooo000Fo`0000Ooo`002oooool000Wooooo1ooo000Fooooo`Ooo`005_ooool7ool0
01Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool0
01Kooooo1ooo000;ooooo`002Oooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Ko
oooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_o
oooo000:ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo
1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`003?ooool000_ooooo0ooo
000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo
000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000=ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`00
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<oooo
o`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0<ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`003Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`003Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0<ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?o
o`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?o
o`006_ooool3ool000gooooo000:ooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`00
6?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`00
3?ooool000Wooooo1ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000Fo`0000Ooo`005_l0
0007ool001Ko00001ooo000Fo`0000Ooo`005_l00007ool001Ko00001ooo000;ooooo`002Oooool7
ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7
ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool000_ooooo0009ooooo`Ooo`005_ooool7ool0
01Kooooo1ooo000Fooooo`Ooo`005_ooool7ool001Kooooo1ooo000Fooooo`Ooo`005_ooool7ool0
01Kooooo1ooo000Fooooo`Ooo`002oooool000[ooooo1Ooo000Hooooo`Goo`006?ooool5ool001So
oooo1Ooo000Hooooo`Goo`006?ooool5ool001Sooooo1Ooo000Hooooo`Goo`006?ooool5ool001So
oooo1Ooo000<ooooo`002oooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool001[ooooo
0ooo000Jooooo`?oo`006_ooool3ool001[ooooo0ooo000Jooooo`?oo`006_ooool3ool000gooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0500054, \
0.00383279, 0.00383279}},
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]],

Cell[BoxData[
    \(\(ReplaceEdges[
        m, \[IndentingNewLine]Neighborhood \[Rule] 
          Cycle[100]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ShowGraph[m];\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.909091 0.0454545 0.909091 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 0 0 r
.005 w
[ ] 0 setdash
.95365 .52854 m
.95096 .55697 L
s
.95365 .52854 m
.95455 .5 L
s
.95096 .55697 m
.94649 .58517 L
s
.94649 .58517 m
.94027 .61304 L
s
.94027 .61304 m
.9323 .64046 L
s
.9323 .64046 m
.92263 .66733 L
s
.92263 .66733 m
.91129 .69354 L
s
.91129 .69354 m
.89832 .71898 L
s
.89832 .71898 m
.88379 .74356 L
s
.88379 .74356 m
.86773 .76718 L
s
.86773 .76718 m
.85023 .78974 L
s
.85023 .78974 m
.83135 .81116 L
s
.83135 .81116 m
.81116 .83135 L
s
.81116 .83135 m
.78974 .85023 L
s
.78974 .85023 m
.76718 .86773 L
s
.76718 .86773 m
.74356 .88379 L
s
.74356 .88379 m
.71898 .89832 L
s
.71898 .89832 m
.69354 .91129 L
s
.69354 .91129 m
.66733 .92263 L
s
.66733 .92263 m
.64046 .9323 L
s
.64046 .9323 m
.61304 .94027 L
s
.61304 .94027 m
.58517 .94649 L
s
.58517 .94649 m
.55697 .95096 L
s
.55697 .95096 m
.52854 .95365 L
s
.52854 .95365 m
.5 .95455 L
s
.5 .95455 m
.47146 .95365 L
s
.47146 .95365 m
.44303 .95096 L
s
.44303 .95096 m
.41483 .94649 L
s
.41483 .94649 m
.38696 .94027 L
s
.38696 .94027 m
.35954 .9323 L
s
.35954 .9323 m
.33267 .92263 L
s
.33267 .92263 m
.30646 .91129 L
s
.30646 .91129 m
.28102 .89832 L
s
.28102 .89832 m
.25644 .88379 L
s
.25644 .88379 m
.23282 .86773 L
s
.23282 .86773 m
.21026 .85023 L
s
.21026 .85023 m
.18884 .83135 L
s
.18884 .83135 m
.16865 .81116 L
s
.16865 .81116 m
.14977 .78974 L
s
.14977 .78974 m
.13227 .76718 L
s
.13227 .76718 m
.11621 .74356 L
s
.11621 .74356 m
.10168 .71898 L
s
.10168 .71898 m
.08871 .69354 L
s
.08871 .69354 m
.07737 .66733 L
s
.07737 .66733 m
.0677 .64046 L
s
.0677 .64046 m
.05973 .61304 L
s
.05973 .61304 m
.05351 .58517 L
s
.05351 .58517 m
.04904 .55697 L
s
.04904 .55697 m
.04635 .52854 L
s
.04635 .52854 m
.04545 .5 L
s
.04545 .5 m
.04635 .47146 L
s
.04635 .47146 m
.04904 .44303 L
s
.04904 .44303 m
.05351 .41483 L
s
.05351 .41483 m
.05973 .38696 L
s
.05973 .38696 m
.0677 .35954 L
s
.0677 .35954 m
.07737 .33267 L
s
.07737 .33267 m
.08871 .30646 L
s
.08871 .30646 m
.10168 .28102 L
s
.10168 .28102 m
.11621 .25644 L
s
.11621 .25644 m
.13227 .23282 L
s
.13227 .23282 m
.14977 .21026 L
s
.14977 .21026 m
.16865 .18884 L
s
.16865 .18884 m
.18884 .16865 L
s
.18884 .16865 m
.21026 .14977 L
s
.21026 .14977 m
.23282 .13227 L
s
.23282 .13227 m
.25644 .11621 L
s
.25644 .11621 m
.28102 .10168 L
s
.28102 .10168 m
.30646 .08871 L
s
.30646 .08871 m
.33267 .07737 L
s
.33267 .07737 m
.35954 .0677 L
s
.35954 .0677 m
.38696 .05973 L
s
.38696 .05973 m
.41483 .05351 L
s
.41483 .05351 m
.44303 .04904 L
s
.44303 .04904 m
.47146 .04635 L
s
.47146 .04635 m
.5 .04545 L
s
.5 .04545 m
.52854 .04635 L
s
.52854 .04635 m
.55697 .04904 L
s
.55697 .04904 m
.58517 .05351 L
s
.58517 .05351 m
.61304 .05973 L
s
.61304 .05973 m
.64046 .0677 L
s
.64046 .0677 m
.66733 .07737 L
s
.66733 .07737 m
.69354 .08871 L
s
.69354 .08871 m
.71898 .10168 L
s
.71898 .10168 m
.74356 .11621 L
s
.74356 .11621 m
.76718 .13227 L
s
.76718 .13227 m
.78974 .14977 L
s
.78974 .14977 m
.81116 .16865 L
s
.81116 .16865 m
.83135 .18884 L
s
.83135 .18884 m
.85023 .21026 L
s
.85023 .21026 m
.86773 .23282 L
s
.86773 .23282 m
.88379 .25644 L
s
.88379 .25644 m
.89832 .28102 L
s
.89832 .28102 m
.91129 .30646 L
s
.91129 .30646 m
.92263 .33267 L
s
.92263 .33267 m
.9323 .35954 L
s
.9323 .35954 m
.94027 .38696 L
s
.94027 .38696 m
.94649 .41483 L
s
.94649 .41483 m
.95096 .44303 L
s
.95096 .44303 m
.95365 .47146 L
s
.95365 .47146 m
.95455 .5 L
s
1 0 0 r
.025 w
.95365 .52854 Mdot
.95096 .55697 Mdot
.94649 .58517 Mdot
.94027 .61304 Mdot
.9323 .64046 Mdot
.92263 .66733 Mdot
.91129 .69354 Mdot
.89832 .71898 Mdot
.88379 .74356 Mdot
.86773 .76718 Mdot
.85023 .78974 Mdot
.83135 .81116 Mdot
.81116 .83135 Mdot
.78974 .85023 Mdot
.76718 .86773 Mdot
.74356 .88379 Mdot
.71898 .89832 Mdot
.69354 .91129 Mdot
.66733 .92263 Mdot
.64046 .9323 Mdot
.61304 .94027 Mdot
.58517 .94649 Mdot
.55697 .95096 Mdot
.52854 .95365 Mdot
.5 .95455 Mdot
.47146 .95365 Mdot
.44303 .95096 Mdot
.41483 .94649 Mdot
.38696 .94027 Mdot
.35954 .9323 Mdot
.33267 .92263 Mdot
.30646 .91129 Mdot
.28102 .89832 Mdot
.25644 .88379 Mdot
.23282 .86773 Mdot
.21026 .85023 Mdot
.18884 .83135 Mdot
.16865 .81116 Mdot
.14977 .78974 Mdot
.13227 .76718 Mdot
.11621 .74356 Mdot
.10168 .71898 Mdot
.08871 .69354 Mdot
.07737 .66733 Mdot
.0677 .64046 Mdot
.05973 .61304 Mdot
.05351 .58517 Mdot
.04904 .55697 Mdot
.04635 .52854 Mdot
.04545 .5 Mdot
.04635 .47146 Mdot
.04904 .44303 Mdot
.05351 .41483 Mdot
.05973 .38696 Mdot
.0677 .35954 Mdot
.07737 .33267 Mdot
.08871 .30646 Mdot
.10168 .28102 Mdot
.11621 .25644 Mdot
.13227 .23282 Mdot
.14977 .21026 Mdot
.16865 .18884 Mdot
.18884 .16865 Mdot
.21026 .14977 Mdot
.23282 .13227 Mdot
.25644 .11621 Mdot
.28102 .10168 Mdot
.30646 .08871 Mdot
.33267 .07737 Mdot
.35954 .0677 Mdot
.38696 .05973 Mdot
.41483 .05351 Mdot
.44303 .04904 Mdot
.47146 .04635 Mdot
.5 .04545 Mdot
.52854 .04635 Mdot
.55697 .04904 Mdot
.58517 .05351 Mdot
.61304 .05973 Mdot
.64046 .0677 Mdot
.66733 .07737 Mdot
.69354 .08871 Mdot
.71898 .10168 Mdot
.74356 .11621 Mdot
.76718 .13227 Mdot
.78974 .14977 Mdot
.81116 .16865 Mdot
.83135 .18884 Mdot
.85023 .21026 Mdot
.86773 .23282 Mdot
.88379 .25644 Mdot
.89832 .28102 Mdot
.91129 .30646 Mdot
.92263 .33267 Mdot
.9323 .35954 Mdot
.94027 .38696 Mdot
.94649 .41483 Mdot
.95096 .44303 Mdot
.95365 .47146 Mdot
.95455 .5 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Q_ooool3ool000Gooooo0ooo0005ooooo`?oo`00Qoooool007kooooo0ooo0004ooooo`Go
o`000oooool5ool000?ooooo1Ooo0004ooooo`?oo`00Ooooool007Gooooo0ooo0005ooooo`Goo`00
0_ooool7ool00003oooooooo003oo`0000Goo`0000?oooooool00?oo00001Ooo0002ooooo`Goo`00
1?ooool3ool007Oooooo001dooooo`Goo`000oooool7ool00003o`000?oo003oo`0000Goo`0000?o
0000ool00?oo00001Ooo00000ol0003oo`00ool00005ool00003o`000?oo003oo`0000Goo`000_oo
ool5ool007Kooooo001]ooooo`?oo`000oooool7ool00003ooooool0003oo`0000Koo`0000?ooooo
ool00?oo00001Ooo00000oooooooo`00ool00005ool00003oooooooo003oo`0000Goo`0000?ooooo
ool00?oo00001Ooo00000ol0003oo`00ool00005ool000?ooooo0ooo001_ooooo`00K?ooool5ool0
00;ooooo1ooo00000ol0003oooooool00006ool000;ooooo1Ooo0003ooooo`Goo`000oooool5ool0
00;ooooo1ooo00000oooooooo`00ool00005ool000;ooooo1Ooo001^ooooo`00I_ooool3ool000;o
oooo1ooo00000ol0003oo`00ool00005ool000?ooooo1Ooo0004ooooo`?oo`001Oooool3ool000Go
oooo0ooo0004ooooo`Goo`000_ooool7ool00003o`000?oo003oo`0000Goo`000oooool3ool006Oo
oooo001Uooooo`Goo`0000?oooooool00?oo00001Ooo0002ooooo`Goo`001Oooool3ool001gooooo
0ooo0004ooooo`Goo`000_ooool7ool000;ooooo1Ooo001Vooooo`00I?ooool>ool000?ooooo0ooo
000^ooooo`?oo`000oooool7ool00003o`000?oo003oo`0000Goo`00IOooool005kooooo0ooo0003
ooooo`Ooo`0000?oooooool00?oo00000ooo000looooo`Goo`000_ooool7ool000?ooooo0ooo001O
ooooo`00GOooool5ool00003ooooool0003oo`0000Koo`000_ooool3ool003kooooo0ooo0003oooo
o`Ooo`0000?o0000oooooooo00001?oo001Nooooo`00G?ooool7ool000;ooooo1Ooo001;ooooo`Go
o`000_ooool7ool005gooooo001Fooooo`?oo`000oooool7ool000?ooooo0ooo001=ooooo`?oo`00
0oooool7ool000;ooooo0ooo001Hooooo`00EOooool5ool00003ooooool0003oo`0000Koo`00FOoo
ool7ool00003o`000?oo003oo`0000?oo`00Eoooool005Cooooo1ooo0002ooooo`Goo`00Foooool5
ool00003oooooooo003oo`0000Goo`00E_ooool005Cooooo1ooo0003ooooo`?oo`00GOooool3ool0
00;ooooo1ooo001Fooooo`00Coooool3ool000;ooooo1ooo001Xooooo`Ooo`0000?o0000oooooooo
ool00ooo001@ooooo`00C_ooool5ool00003o`000?ooooooo`0000Coo`00J_ooool5ool000;ooooo
00?o0000ool00?oo00000ooo001?ooooo`00COooool7ool000;ooooo0ooo001/ooooo`?oo`000ooo
ool7ool004kooooo001=ooooo`Ooo`00Moooool7ool004kooooo0018ooooo`?oo`000_ooool7ool0
07Oooooo1ooo0002ooooo`?oo`00BOooool004Oooooo1Ooo00000ol0003oooooool00004ool007Wo
oooo1Ooo00000ooooooo0000ool00004ool004Sooooo0016ooooo`Ooo`000_ooool3ool007_ooooo
0ooo0002ooooo`Ooo`00Aoooool004Kooooo1ooo0025ooooo`Ooo`00Aoooool004Kooooo1ooo0025
ooooo`Ooo`00Aoooool0047ooooo0ooo00000ooooooo0000ooooo`05ool008Oooooo1Ooo00000ooo
oooo0000ooooo`03ool004;ooooo0010ooooo`Goo`000oooool3ool008Wooooo0ooo0003ooooo`Go
o`00@Oooool003oooooo1ooo002Cooooo`Ooo`00@?ooool003oooooo1ooo002Cooooo`Ooo`00@?oo
ool003oooooo1ooo002Cooooo`Ooo`00@?ooool003_ooooo0ooo00000ol0003oooooool00004ool0
09Gooooo1Ooo00000ooooooo0000ool00002ool003cooooo000jooooo`Goo`000_ooool3ool009Oo
oooo0ooo0002ooooo`Goo`00>oooool003Wooooo1ooo002Oooooo`Ooo`00>_ooool003Wooooo1ooo
002Oooooo`Ooo`00>_ooool003Wooooo1ooo002Oooooo`Ooo`00>_ooool003Gooooo0ooo00000ooo
oooo0000ool00004ool00:7ooooo1Ooo00000ol0003oooooool00002ool003Kooooo000dooooo`Go
o`000_ooool3ool00:?ooooo0ooo0002ooooo`Goo`00=Oooool003?ooooo1ooo002[ooooo`Ooo`00
=?ooool003?ooooo1ooo002[ooooo`Ooo`00=?ooool003?ooooo1ooo002[ooooo`Ooo`00=?ooool0
03Cooooo1Ooo002]ooooo`Goo`00=Oooool002oooooo0ooo00000ooooooo0000ooooo`03ool00:oo
oooo0ooo00000ooooooo0000ooooo`03ool0033ooooo000^ooooo`Goo`00^Oooool5ool002oooooo
000]ooooo`Ooo`00]oooool7ool002kooooo000]ooooo`Ooo`00]oooool7ool002kooooo000]oooo
o`Ooo`00]oooool7ool002kooooo000^ooooo`Goo`00^Oooool5ool002oooooo000Yooooo`?oo`00
00?oooooo`000?ooool00ooo002kooooo`?oo`0000?oooooo`000?oo00000_oo000[ooooo`00:?oo
ool5ool00<Cooooo1Ooo000Zooooo`009oooool7ool00<;ooooo1ooo000Yooooo`009oooool7ool0
0<;ooooo1ooo000Yooooo`009oooool7ool00<;ooooo1ooo000Yooooo`00:?ooool5ool00<Cooooo
1Ooo000Zooooo`009?ooool3ool00003ooooool0003oo`0000;oo`00a_ooool3ool00003ooooool0
003oo`0000;oo`009_ooool002?ooooo1Ooo003>ooooo`Goo`009Oooool002;ooooo1ooo003<oooo
o`Ooo`009?ooool002;ooooo1ooo003<ooooo`Ooo`009?ooool002;ooooo1ooo003<ooooo`Ooo`00
9?ooool002?ooooo1Ooo003>ooooo`Goo`009Oooool002Cooooo0ooo003@ooooo`?oo`0000?o0000
ooooooooool08oooool0023ooooo0ooo00000ol0003oooooooooo`3Eooooo`04o`000?oo003oo`00
ool0027ooooo000Oooooo`Goo`00eoooool5ool0023ooooo000Nooooo`Ooo`00eOooool7ool001oo
oooo000Nooooo`Ooo`00eOooool7ool001oooooo000Nooooo`Ooo`00eOooool7ool001oooooo000O
ooooo`Goo`00eoooool5ool0023ooooo000Pooooo`?oo`00fOooool3ool0027ooooo000Looooo`?o
o`0000?o0000ooooooooool0gOooool01?l0003oo`00ool00?oo000Mooooo`006oooool5ool00=oo
oooo1Ooo000Looooo`006_ooool7ool00=gooooo1ooo000Kooooo`006_ooool7ool00=gooooo1ooo
000Kooooo`006_ooool7ool00=gooooo1ooo000Kooooo`006oooool5ool00=oooooo1Ooo000Loooo
o`007?ooool3ool00>7ooooo0ooo000Mooooo`006oooool00ol0003oooooooooo`3Uooooo`03o`00
0?oooooooooo01[ooooo000Hooooo`?oo`00jOooool3ool001Wooooo000Gooooo`Goo`00ioooool5
ool001Sooooo000Fooooo`Ooo`00iOooool7ool001Oooooo000Fooooo`Ooo`00iOooool7ool001Oo
oooo000Fooooo`Ooo`00iOooool7ool001Oooooo000Gooooo`Goo`00ioooool5ool001Sooooo000H
ooooo`?oo`00jOooool3ool001Wooooo000Eooooo`?oo`00koooool3ool001Kooooo000Dooooo`Go
o`00kOooool5ool001Gooooo000Cooooo`Ooo`00joooool7ool001Cooooo000Cooooo`Ooo`00jooo
ool7ool001Cooooo000Cooooo`Ooo`00joooool7ool001Cooooo000Dooooo`Goo`00kOooool5ool0
01Gooooo000Eooooo`?oo`00koooool3ool001Kooooo000Eooooo`03o`000?oooooooooo0?7ooooo
00?o0000ooooooooool05?ooool001;ooooo0ooo003eooooo`?oo`004oooool0017ooooo1Ooo003c
ooooo`Goo`004_ooool0013ooooo1ooo003aooooo`Ooo`004Oooool0013ooooo1ooo003aooooo`Oo
o`004Oooool0013ooooo1ooo003aooooo`Ooo`004Oooool0017ooooo1Ooo003cooooo`Goo`004_oo
ool001;ooooo0ooo003eooooo`?oo`004oooool001;ooooo00?o0000ooooooooool0moooool00ol0
003oooooooooo`0Aooooo`004?ooool3ool00?Wooooo0ooo000Aooooo`003oooool5ool00?Oooooo
1Ooo000@ooooo`003_ooool7ool00?Gooooo1ooo000?ooooo`003_ooool7ool00?Gooooo1ooo000?
ooooo`003_ooool7ool00?Gooooo1ooo000?ooooo`003oooool5ool00?Oooooo1Ooo000@ooooo`00
4?ooool3ool00?Wooooo0ooo000Aooooo`004?ooool00ol0003oooooooooo`3kooooo`03o`000?oo
oooooooo00oooooo000>ooooo`?oo`00oOooool3ool000oooooo000=ooooo`Goo`00noooool5ool0
00kooooo000<ooooo`Ooo`00nOooool7ool000gooooo000<ooooo`Ooo`00nOooool7ool000gooooo
000<ooooo`Ooo`00nOooool7ool000gooooo000=ooooo`Goo`00noooool5ool000kooooo000>oooo
o`?oo`00oOooool3ool000oooooo000?ooooo`03o`000?oooooooooo0?gooooo00?o0000oooooooo
ool03_ooool000gooooo0ooo003oooooo`?oo`003_ooool000cooooo1Ooo003mooooo`Goo`003Ooo
ool000_ooooo1ooo003kooooo`Ooo`003?ooool000_ooooo1ooo003kooooo`Ooo`003?ooool000_o
oooo1ooo003kooooo`Ooo`003?ooool000cooooo1Ooo003mooooo`Goo`003Oooool000gooooo0ooo
003oooooo`?oo`003_ooool000kooooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`0=
ooooo`003?ooool3ool00?oooooo0_ooool3ool000gooooo000;ooooo`Goo`00ooooool5ool000co
oooo000:ooooo`Ooo`00oOooool7ool000_ooooo000:ooooo`Ooo`00oOooool7ool000_ooooo000:
ooooo`Ooo`00oOooool7ool000_ooooo000;ooooo`Goo`00ooooool5ool000cooooo000<ooooo`?o
o`00ooooool2ooooo`?oo`003Oooool000gooooo00?o0000ooooooooool0ooooool2ooooo`03o`00
0?oooooooooo00cooooo000;ooooo`?oo`00ooooool3ooooo`?oo`003Oooool000[ooooo1Ooo003o
ooooo`7ooooo1Ooo000<ooooo`002Oooool7ool00?kooooo1ooo000;ooooo`002Oooool7ool00?ko
oooo1ooo000;ooooo`002Oooool7ool00?kooooo1ooo000;ooooo`002_ooool5ool00?oooooo0Ooo
ool5ool000cooooo000;ooooo`?oo`00ooooool3ooooo`?oo`003Oooool000gooooo00?o0000oooo
ooooool0ooooool2ooooo`03o`000?oooooooooo00cooooo000<ooooo`?oo`00ooooool2ooooo`?o
o`003Oooool000_ooooo1Ooo003oooooo`Goo`003?ooool000[ooooo1ooo003mooooo`Ooo`002ooo
ool000[ooooo1ooo003mooooo`Ooo`002oooool000[ooooo1ooo003mooooo`Ooo`002oooool000_o
oooo1Ooo003oooooo`Goo`003?ooool000cooooo0ooo003oooooo`;ooooo0ooo000=ooooo`003Ooo
ool00ol0003oooooooooo`3oooooo`;ooooo00?o0000ooooooooool03?ooool000gooooo0ooo003o
ooooo`?oo`003_ooool000cooooo1Ooo003mooooo`Goo`003Oooool000_ooooo1ooo003kooooo`Oo
o`003?ooool000_ooooo1ooo003kooooo`Ooo`003?ooool000_ooooo1ooo003kooooo`Ooo`003?oo
ool000cooooo1Ooo003mooooo`Goo`003Oooool000gooooo0ooo003oooooo`?oo`003_ooool000ko
oooo00?o0000ooooooooool0ooooool00ol0003oooooooooo`0=ooooo`003oooool00ol0003ooooo
ooooo`3mooooo`03o`000?oooooooooo00kooooo000>ooooo`?oo`00oOooool3ool000oooooo000=
ooooo`Goo`00noooool5ool000kooooo000<ooooo`Ooo`00nOooool7ool000gooooo000<ooooo`Oo
o`00nOooool7ool000gooooo000<ooooo`Ooo`00nOooool7ool000gooooo000=ooooo`Goo`00nooo
ool5ool000kooooo000>ooooo`?oo`00oOooool3ool000oooooo000@ooooo`03o`000?oooooooooo
0?_ooooo00?o0000ooooooooool03oooool0013ooooo0ooo003iooooo`?oo`004Oooool000oooooo
1Ooo003gooooo`Goo`004?ooool000kooooo1ooo003eooooo`Ooo`003oooool000kooooo1ooo003e
ooooo`Ooo`003oooool000kooooo1ooo003eooooo`Ooo`003oooool000oooooo1Ooo003gooooo`Go
o`004?ooool0013ooooo0ooo003iooooo`?oo`004Oooool001;ooooo0ooo003eooooo`?oo`004ooo
ool0017ooooo1Ooo003cooooo`Goo`004_ooool0013ooooo1ooo003aooooo`Ooo`004Oooool0013o
oooo1ooo003aooooo`Ooo`004Oooool0013ooooo1ooo003aooooo`Ooo`004Oooool0017ooooo1Ooo
003cooooo`Goo`004_ooool001;ooooo0ooo003eooooo`?oo`004oooool001Cooooo00?o0000oooo
ooooool0loooool00ol0003oooooooooo`0Cooooo`005Oooool3ool00>oooooo0ooo000Fooooo`00
5?ooool5ool00>gooooo1Ooo000Eooooo`004oooool7ool00>_ooooo1ooo000Dooooo`004oooool7
ool00>_ooooo1ooo000Dooooo`004oooool7ool00>_ooooo1ooo000Dooooo`005?ooool5ool00>go
oooo1Ooo000Eooooo`005Oooool3ool00>oooooo0ooo000Fooooo`005oooool00ol0003ooooooooo
o`3]ooooo`03o`000?oooooooooo01Kooooo000Hooooo`?oo`00jOooool3ool001Wooooo000Goooo
o`Goo`00ioooool5ool001Sooooo000Fooooo`Ooo`00iOooool7ool001Oooooo000Fooooo`Ooo`00
iOooool7ool001Oooooo000Fooooo`Ooo`00iOooool7ool001Oooooo000Gooooo`Goo`00ioooool5
ool001Sooooo000Hooooo`?oo`00jOooool3ool001Wooooo000Kooooo`04o`000?oo003oo`00ool0
0>7ooooo0ooo00000ol0003oooooooooo`0Jooooo`006oooool5ool00=oooooo1Ooo000Looooo`00
6_ooool7ool00=gooooo1ooo000Kooooo`006_ooool7ool00=gooooo1ooo000Kooooo`006_ooool7
ool00=gooooo1ooo000Kooooo`006oooool5ool00=oooooo1Ooo000Looooo`007?ooool3ool00>7o
oooo0ooo000Mooooo`007oooool01?l0003oo`00ool00?oo003Iooooo`?oo`0000?o0000oooooooo
ool07_ooool001oooooo1Ooo003Gooooo`Goo`008?ooool001kooooo1ooo003Eooooo`Ooo`007ooo
ool001kooooo1ooo003Eooooo`Ooo`007oooool001kooooo1ooo003Eooooo`Ooo`007oooool001oo
oooo1Ooo003Gooooo`Goo`008?ooool0023ooooo0ooo003Iooooo`?oo`008Oooool002?ooooo00Co
0000ool00?oo003oo`00d?ooool3ool00003ooooool0003ooooo02?ooooo000Sooooo`Goo`00c_oo
ool5ool002Gooooo000Rooooo`Ooo`00c?ooool7ool002Cooooo000Rooooo`Ooo`00c?ooool7ool0
02Cooooo000Rooooo`Ooo`00c?ooool7ool002Cooooo000Sooooo`Goo`00c_ooool5ool002Gooooo
000Tooooo`?oo`0000?o0000oooooooo00000_oo0036ooooo`?oo`000_ooool3ool002Kooooo000X
ooooo`Goo`00a?ooool5ool00003o`000?oooooooooo02Oooooo000Wooooo`Ooo`00`_ooool7ool0
02Wooooo000Wooooo`Ooo`00`_ooool7ool002Wooooo000Wooooo`Ooo`00`_ooool7ool002Wooooo
000Xooooo`Goo`00a?ooool5ool002[ooooo000Yooooo`?oo`0000?oooooo`000?ooool00ooo002k
ooooo`?oo`0000?oooooo`000?oo00000_oo000[ooooo`00;_ooool5ool00;Wooooo1Ooo000_oooo
o`00;Oooool7ool00;Oooooo1ooo000^ooooo`00;Oooool7ool00;Oooooo1ooo000^ooooo`00;Ooo
ool7ool00;Oooooo1ooo000^ooooo`00;_ooool5ool00;Wooooo1Ooo000_ooooo`00;oooool3ool0
0003ooooool0003ooooo00?oo`00[oooool3ool00003ooooool0003ooooo00?oo`00<?ooool003Co
oooo1Ooo002]ooooo`Goo`00=Oooool003?ooooo1ooo002[ooooo`Ooo`00=?ooool003?ooooo1ooo
002[ooooo`Ooo`00=?ooool003?ooooo1ooo002[ooooo`Ooo`00=?ooool003Cooooo1Ooo002]oooo
o`Goo`00=Oooool003Gooooo0ooo00000ooooooo0000ooooo`03ool00:?ooooo0ooo00000ooooooo
0000ooooo`03ool003Kooooo000jooooo`Goo`00XOooool5ool003_ooooo000iooooo`Ooo`00Wooo
ool7ool003[ooooo000iooooo`Ooo`00Woooool7ool003[ooooo000iooooo`Ooo`00Woooool7ool0
03[ooooo000jooooo`Goo`0000?o0000oooooooo00000_oo002Gooooo`?oo`0000?oooooo`000?oo
00001?oo000kooooo`00>oooool3ool000;ooooo1Ooo002Eooooo`Goo`000_ooool3ool003cooooo
000oooooo`Ooo`00Toooool7ool0043ooooo000oooooo`Ooo`00Toooool7ool0043ooooo000ooooo
o`Ooo`000_ooool3ool008Wooooo0ooo0002ooooo`Ooo`00@?ooool0043ooooo1Ooo00000ooooooo
0000ool00004ool008Oooooo1Ooo00000ol0003oooooool00004ool0047ooooo0011ooooo`?oo`00
0_ooool7ool008Gooooo1ooo0002ooooo`?oo`00@_ooool004Kooooo1ooo0025ooooo`Ooo`00Aooo
ool004Kooooo1ooo0002ooooo`?oo`00Noooool3ool000;ooooo1ooo0017ooooo`00Aoooool5ool0
0003ooooool0003oo`0000Coo`00NOooool5ool00003o`000?ooooooo`0000Coo`00B?ooool004So
oooo0ooo0002ooooo`Ooo`00Moooool7ool000;ooooo0ooo0019ooooo`00COooool7ool007Oooooo
1ooo001>ooooo`00COooool7ool000;ooooo0ooo001/ooooo`?oo`000oooool7ool004kooooo001>
ooooo`Goo`0000?oooooo`000?oo00001?oo001Zooooo`Goo`0000?oooooo`000?ooool01Ooo001?
ooooo`00Coooool3ool000;ooooo1ooo001Xooooo`Ooo`000oooool3ool0053ooooo001Dooooo`Oo
o`000oooool3ool005gooooo0ooo0002ooooo`Ooo`00E_ooool005Cooooo1ooo00000ol0003ooooo
ool00004ool005_ooooo1Ooo00000oooooooo`00ool00005ool005Kooooo001Eooooo`Goo`000_oo
ool7ool005Wooooo1ooo00000oooooooo`00ool00003ool005Oooooo001Fooooo`?oo`000oooool7
ool000?ooooo0ooo001=ooooo`?oo`000oooool7ool000;ooooo0ooo001Hooooo`00G?ooool7ool0
0003o`000?ooooooo`0000Coo`00Boooool5ool00003ooooool0003oo`0000Koo`00GOooool005go
oooo1Ooo0002ooooo`Ooo`000_ooool3ool003kooooo0ooo0003ooooo`Ooo`000_ooool5ool005ko
oooo001Nooooo`?oo`000oooool7ool00003oooooooo003oo`0000?oo`00??ooool5ool000;ooooo
1ooo0003ooooo`?oo`00Goooool006Cooooo3_oo0003ooooo`?oo`00;_ooool3ool000?ooooo1ooo
00000ol0003oo`00ool00005ool006Gooooo001Uooooo`Goo`0000?oooooool00?oo00001Ooo0002
ooooo`Goo`001Oooool3ool001gooooo0ooo0004ooooo`Goo`000_ooool7ool000;ooooo1Ooo001V
ooooo`00I_ooool3ool000;ooooo1ooo00000ol0003oo`00ool00005ool000?ooooo1Ooo0004oooo
o`?oo`003Oooool3ool000Cooooo1Ooo0002ooooo`Ooo`0000?o0000ool00?oo00001Ooo0003oooo
o`?oo`00Ioooool006cooooo1Ooo0002ooooo`Ooo`000_l00007ool000;ooooo1Ooo0004ooooo`?o
o`001?ooool5ool000;ooooo1ooo00000ol0003oo`00ool00005ool000;ooooo1Ooo001^ooooo`00
KOooool3ool000?ooooo1ooo0002ooooo`Ooo`0000?o0000ool00?oo00001Ooo0002ooooo`Goo`00
0_ooool7ool00003o`000?oo003oo`0000Goo`0000?oooooool00?oo00001Ooo0003ooooo`?oo`00
Koooool007Cooooo1Ooo0003ooooo`Ooo`0000?oooooool00?oo00001Ooo00000ol0003oo`00ool0
0005ool00003o`000?oo003oo`0000Goo`0000?oooooool00?oo00001Ooo0002ooooo`Goo`00M_oo
ool007Gooooo0ooo0005ooooo`Goo`000_ooool7ool00003oooooooo003oo`0000Goo`0000?ooooo
ool00?oo00001Ooo0002ooooo`Goo`001?ooool3ool007Oooooo001nooooo`?oo`001?ooool5ool0
00;ooooo1ooo0002ooooo`Goo`001?ooool3ool007oooooo0026ooooo`?oo`001?ooool5ool000Co
oooo0ooo0027ooooo`00S_ooool3ool008oooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003ooooo
ob7ooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.0500054, -0.0500054, \
0.00383279, 0.00383279}},
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]],

Cell["Overspecifying neighborhoods gives an error.", "Text",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ReplaceEdges[
        m, \[IndentingNewLine]InteractionNeighborhood \[Rule] 
          GridGraph[10, 10], \[IndentingNewLine]UpdateNeighborhood \[Rule] 
          RandomTree[100], \[IndentingNewLine]Neighborhood \[Rule] 
          Cycle[100]\[IndentingNewLine]];\)\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[BoxData[
    \(ReplaceEdges::"nbhderr3" \(\(:\)\(\ \)\) 
      "Too many neighborhoods were specified. You can either pass values for \
InteractionNeighborhood and/or UpdateNeighborhood, or a value for \
Neighborhood, but not both."\)], "Message",
  CellLabel->"From In[6]:=",
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 701}},
WindowSize->{650, 568},
WindowMargins->{{Automatic, 247}, {Automatic, 52}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:13"->{
    Cell[1776, 53, 80, 1, 38, "ObjectName",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[1859, 56, 332, 12, 32, "Usage",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[2194, 70, 141, 4, 24, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[2338, 76, 1623, 42, 229, "3ColumnTable",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[3964, 120, 370, 12, 40, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4337, 134, 176, 4, 24, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4516, 140, 351, 12, 40, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4892, 156, 79, 1, 38, "ExampleSection",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4974, 159, 142, 3, 26, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[5141, 166, 188, 4, 42, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[5332, 172, 74796, 1503, 294, 8642, 681, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80143, 1678, 214, 5, 58, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80382, 1687, 120, 3, 26, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80505, 1692, 20610, 629, 294, 5850, 441, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101130, 2324, 106, 1, 24, "Text",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101261, 2329, 369, 7, 90, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101633, 2338, 327, 6, 61, "Message",
      CellTags->{"b:13", "LocalInteractions:29"}]},
  "LocalInteractions:29"->{
    Cell[1776, 53, 80, 1, 38, "ObjectName",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[1859, 56, 332, 12, 32, "Usage",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[2194, 70, 141, 4, 24, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[2338, 76, 1623, 42, 229, "3ColumnTable",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[3964, 120, 370, 12, 40, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4337, 134, 176, 4, 24, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4516, 140, 351, 12, 40, "Notes",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4892, 156, 79, 1, 38, "ExampleSection",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[4974, 159, 142, 3, 26, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[5141, 166, 188, 4, 42, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[5332, 172, 74796, 1503, 294, 8642, 681, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80143, 1678, 214, 5, 58, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80382, 1687, 120, 3, 26, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[80505, 1692, 20610, 629, 294, 5850, 441, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101130, 2324, 106, 1, 24, "Text",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101261, 2329, 369, 7, 90, "Input",
      CellTags->{"b:13", "LocalInteractions:29"}],
    Cell[101633, 2338, 327, 6, 61, "Message",
      CellTags->{"b:13", "LocalInteractions:29"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:13", 102621, 2365},
  {"LocalInteractions:29", 104360, 2402}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 80, 1, 38, "ObjectName",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[1859, 56, 332, 12, 32, "Usage",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[2194, 70, 141, 4, 24, "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[2338, 76, 1623, 42, 229, "3ColumnTable",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[3964, 120, 370, 12, 40, "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[4337, 134, 176, 4, 24, "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[4516, 140, 351, 12, 40, "Notes",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{
Cell[4892, 156, 79, 1, 38, "ExampleSection",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[4974, 159, 142, 3, 26, "Input",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{
Cell[5141, 166, 188, 4, 42, "Input",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[5332, 172, 74796, 1503, 294, 8642, 681, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]],
Cell[80143, 1678, 214, 5, 58, "Input",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{
Cell[80382, 1687, 120, 3, 26, "Input",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[80505, 1692, 20610, 629, 294, 5850, 441, "GraphicsData", "PostScript", \
"Graphics",
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]],
Cell[101130, 2324, 106, 1, 24, "Text",
  CellTags->{"b:13", "LocalInteractions:29"}],

Cell[CellGroupData[{
Cell[101261, 2329, 369, 7, 90, "Input",
  CellTags->{"b:13", "LocalInteractions:29"}],
Cell[101633, 2338, 327, 6, 61, "Message",
  CellTags->{"b:13", "LocalInteractions:29"}]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

